==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForServersGcpOfferingVaAutoProvisioningArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The Vulnerability Assessment autoprovisioning configuration
 * @property configuration configuration for Vulnerability Assessment autoprovisioning
 * @property enabled Is Vulnerability Assessment auto provisioning enabled
 */
public data class DefenderForServersGcpOfferingVaAutoProvisioningArgs(
    public val configuration: Output<DefenderForServersGcpOfferingConfigurationConfigurationArgs>? =
        null,
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs =
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs.builder()
            .configuration(configuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForServersGcpOfferingVaAutoProvisioningArgs].
 */
@PulumiTagMarker
public class DefenderForServersGcpOfferingVaAutoProvisioningArgsBuilder internal constructor() {
    private var configuration: Output<DefenderForServersGcpOfferingConfigurationConfigurationArgs>? =
        null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value configuration for Vulnerability Assessment autoprovisioning
     */
    @JvmName("ldctbfpssioxwkle")
    public suspend
    fun configuration(`value`: Output<DefenderForServersGcpOfferingConfigurationConfigurationArgs>) {
        this.configuration = value
    }

    /**
     * @param value Is Vulnerability Assessment auto provisioning enabled
     */
    @JvmName("jnjbwlfkwptwjqtd")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value configuration for Vulnerability Assessment autoprovisioning
     */
    @JvmName("jbibqytcsoshvnyx")
    public suspend
    fun configuration(`value`: DefenderForServersGcpOfferingConfigurationConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configuration = mapped
    }

    /**
     * @param argument configuration for Vulnerability Assessment autoprovisioning
     */
    @JvmName("onhssvdcpiutqotm")
    public suspend
    fun configuration(argument: suspend DefenderForServersGcpOfferingConfigurationConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped =
            DefenderForServersGcpOfferingConfigurationConfigurationArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.configuration = mapped
    }

    /**
     * @param value Is Vulnerability Assessment auto provisioning enabled
     */
    @JvmName("jsgmiwtrcfwbfhsp")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): DefenderForServersGcpOfferingVaAutoProvisioningArgs =
        DefenderForServersGcpOfferingVaAutoProvisioningArgs(
            configuration = configuration,
            enabled = enabled,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForServersGcpOfferingVaAutoProvisioningArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The Vulnerability Assessment autoprovisioning configuration
 * @property configuration configuration for Vulnerability Assessment autoprovisioning
 * @property enabled Is Vulnerability Assessment auto provisioning enabled
 */
public data class DefenderForServersGcpOfferingVaAutoProvisioningArgs(
    public val configuration: Output<DefenderForServersGcpOfferingConfigurationConfigurationArgs>? =
        null,
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs =
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingVaAutoProvisioningArgs.builder()
            .configuration(configuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForServersGcpOfferingVaAutoProvisioningArgs].
 */
@PulumiTagMarker
public class DefenderForServersGcpOfferingVaAutoProvisioningArgsBuilder internal constructor() {
    private var configuration: Output<DefenderForServersGcpOfferingConfigurationConfigurationArgs>? =
        null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value configuration for Vulnerability Assessment autoprovisioning
     */
    @JvmName("rosybjibqjakfpeo")
    public suspend
    fun configuration(`value`: Output<DefenderForServersGcpOfferingConfigurationConfigurationArgs>) {
        this.configuration = value
    }

    /**
     * @param value Is Vulnerability Assessment auto provisioning enabled
     */
    @JvmName("exxhopfblldoftub")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value configuration for Vulnerability Assessment autoprovisioning
     */
    @JvmName("hlwknssfgkrnolgr")
    public suspend
    fun configuration(`value`: DefenderForServersGcpOfferingConfigurationConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configuration = mapped
    }

    /**
     * @param argument configuration for Vulnerability Assessment autoprovisioning
     */
    @JvmName("jmnhrvwcvcplsibw")
    public suspend
    fun configuration(argument: suspend DefenderForServersGcpOfferingConfigurationConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped =
            DefenderForServersGcpOfferingConfigurationConfigurationArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.configuration = mapped
    }

    /**
     * @param value Is Vulnerability Assessment auto provisioning enabled
     */
    @JvmName("njtcppqrfrwjwkvf")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): DefenderForServersGcpOfferingVaAutoProvisioningArgs =
        DefenderForServersGcpOfferingVaAutoProvisioningArgs(
            configuration = configuration,
            enabled = enabled,
        )
}
